Api

Struct Api 

pub struct Api<'rofi> { /* private fields */ }
The Rofi API, controlled by a lifetime to be only accessible while Rofi is running.

Implementations

Source

impl Api<'_>

pub fn display_name(&self) -> Option<&str>

Get the display name of the current mode (the text displayed before the colon).

Returns None if there isn’t one, in which case Rofi shows the mode name instead.

pub fn take_display_name(&mut self) -> Option<String>

Take the current display name, leaving None in its place and returning the previous display name. This will cause Rofi to display the mode name instead.

Returns None if there was no previous display name.

pub fn replace_display_name(&mut self, display_name: String) -> Option<String>

Replace the current display name, returning the previous one.

Returns None if there was no previous display name.

pub fn set_display_name<T: Display>(&mut self, display_name: T)

Set the display name of the current mode.

Panics

Panics if the given string contains any interior nul bytes.

pub fn supports_image<P: AsRef<Path>>(&self, path: P) -> bool

Check whether the given file path is an image in one of Rofi’s supported formats, by looking at its file extension.

pub fn query_icon(&mut self, name: &str, size: u32) -> IconRequest

Query the icon theme for an icon with a specific name and size.

name can also be a full path.

Panics

Panics if name contains interior nul bytes.

pub fn query_icon_cstr(&mut self, name: &CStr, size: u32) -> IconRequest

Query the icon theme for an icon with a specific name and size.

name can also be a full path.

pub fn query_icon_wh( &mut self, name: &str, width: u32, height: u32, ) -> IconRequest

Query the icon theme for an icon with a specific name and size.

name can also be a full path.

Panics

Panics if name contains interior nul bytes.

pub fn query_icon_wh_cstr( &mut self, name: &CStr, width: u32, height: u32, ) -> IconRequest

Query the icon theme for an icon with a specific name and size.

name can also be a full path.

pub fn retrieve_icon( &mut self, request: IconRequest, ) -> Result<Surface, IconError>

Finalize an icon request and retrieve the inner icon.

The returned icon will be the best match for the requested size, but you may need to resize it to desired size.

It may be ergonomically preferable to use IconRequest::wait instead of this function.

Errors

Errors if the icon was not found, or an error occurred inside the returned Cairo surface.

pub fn hide(&mut self)

Hides the view.

Be warned that this is a private API, so while we expose it for some use-cases, using it is technically unreliable.